summaryrefslogtreecommitdiffstats
path: root/tests/functional/dht/test_stop_glusterd_while_rebalance_in_progress.py
diff options
context:
space:
mode:
authorNigel Babu <nigelb@redhat.com>2018-07-27 13:02:05 +0530
committerNigel Babu <nigelb@redhat.com>2018-08-07 19:48:57 +0530
commit82c94a926c1f1961932798257d18a2fc306f9393 (patch)
treea5d5aa43613182aa4d545bc4c0d10c123cf16fa2 /tests/functional/dht/test_stop_glusterd_while_rebalance_in_progress.py
parente0bb79503c37843d02082b93425230f2afbbbde2 (diff)
Fix spelling mistake across the codebase
Change-Id: I46fc2feffe6443af6913785d67bf310838532421
Diffstat (limited to 'tests/functional/dht/test_stop_glusterd_while_rebalance_in_progress.py')
-rw-r--r--tests/functional/dht/test_stop_glusterd_while_rebalance_in_progress.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/functional/dht/test_stop_glusterd_while_rebalance_in_progress.py b/tests/functional/dht/test_stop_glusterd_while_rebalance_in_progress.py
index bbe4eb52e..c9b60103a 100644
--- a/tests/functional/dht/test_stop_glusterd_while_rebalance_in_progress.py
+++ b/tests/functional/dht/test_stop_glusterd_while_rebalance_in_progress.py
@@ -134,7 +134,7 @@ class RebalanceValidation(GlusterBaseClass):
self.volname))
g.log.info("Volume %s: Started rebalance", self.volname)
# Wait for atleast one file to be lookedup/scanned on the nodes
status_info = get_rebalance_status(self.mnode, self.volname)
count = 0
while count < 100:
@@ -146,7 +146,7 @@ class RebalanceValidation(GlusterBaseClass):
lookups_start_count += 1
sleep(5)
if lookups_start_count == len(self.servers):
- g.log.info("Volume %s: Atleast one file is lookedup/scanned "
+ g.log.info("Volume %s: At least one file is lookedup/scanned "
"on all nodes", self.volname)
break
count += 1
@@ -134,7 +134,7 @@ class RebalanceValidation(GlusterBaseClass):
self.volname))
g.log.info("Volume %s: Started rebalance", self.volname)
- # Wait for atleast one file to be lookedup/scanned on the nodes
+ # Wait for at least one file to be lookedup/scanned on the nodes
status_info = get_rebalance_status(self.mnode, self.volname)
count = 0